overlayOpacity property
The value of the dark layer overtop the backdrop. a double value between 0.0 and 1.0.
Implementation
final double? overlayOpacity;
The value of the dark layer overtop the backdrop. a double value between 0.0 and 1.0.
final double? overlayOpacity;