BackdropAppBar class

Constructors

BackdropAppBar({Widget? title, Icon? leading, SearchBox? searchBox, List<Widget>? actions})
const

Properties

actions List<Widget>?
A list of Widgets that is placed on the topRight of the SlidingBox.backdrop.
final
hashCode int
The hash code for this object.
no setterinherited
leading Icon?
A Icon Widget that is placed in left of the BackdropAppBar title.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
An search box to display at the top of the SlidingBox.backdrop. if non-null, an search Icon displayed on topRight of the backdrop.
final
title Widget?
A Widget that is placed on the topLeft of the SlidingBox.backdrop.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited