BoxController class

Inheritance

Constructors

BoxController()

Properties

backdropWidth double
Returns current backdrop box Backdrop.width.
no setter
boxWidth double
Returns current box SlidingBox.width.
no setter
getPosition double
Returns current box position (a value between 0.0 and 1.0).
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isAttached bool
Determine if the SlidingBox.controller is attached to an instance of the SlidingBox (this property must be true before any other BoxController functions can be used).
no setter
isBoxClosed bool
Returns whether or not the box is close or collapsed.
no setter
isBoxOpen bool
Returns whether or not the box is open.
no setter
isBoxVisible bool
Returns whether or not the box is visible.
no setter
isSearchBoxVisible bool
Returns whether or not the search box is visible.
no setter
maxHeight double
Returns current box SlidingBox.maxHeight.
no setter
minHeight double
Returns current box SlidingBox.minHeight.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value MenuIconValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
closeBox() Future<void>
Closes the sliding box with animation. (i.e. to the SlidingBox.minHeight).
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
hideBox() Future<void>
Hides the sliding box (i.e. is invisible).
hideSearchBox() Future<void>
Hides the search box (i.e. is invisible).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
openBox() Future<void>
Opens the sliding box with animation. (i.e. to the SlidingBox.maxHeight).
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setPosition(double value) Future<void>
setSearchBody({required Widget child}) Future<void>
Sets the sliding box position with animation. (a value between 0.0 and 1.0).
showBox() Future<void>
Shows the sliding box (i.e. is visible).
showSearchBox() Future<void>
Shows the search box (i.e. is visible).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited