Backdrop class
Constructors
Properties
- appBar → BackdropAppBar?
-
An app bar to display at the top of the SlidingBox.backdrop.
final
- backgroundGradient → Gradient?
-
The gradient color to fill the background of the backdrop. if color and
backgroundGradient are both non-null, color will be used.
final
- body → Widget?
-
A Widget that is placed in the SlidingBox.backdrop and behind
the sliding box.
final
- color → Color?
-
The color to fill the background of the backdrop body.
final
- fading → bool?
-
If set to true, the backdrop body fades out when the sliding box opened.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- moving → bool?
-
If set to true, the backdrop body moving up when the sliding box opened.
final
- overlay → bool?
-
If set to true, a dark layer displayed overtop the backdrop when
sliding box opened.
final
- overlayOpacity → double?
-
The value of the dark layer overtop the backdrop. a double value between
0.0 and 1.0.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
The width of the backdrop body.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited