SearchBox class
Constructors
SearchBox ({required TextEditingController controller , Icon ? leading = const Icon(Icons.arrow_back_ios_rounded) , Color ? color = Colors.white , InputDecoration ? inputDecoration = const InputDecoration(border: InputBorder.none, hintText: 'Search...') , BorderRadius ? borderRadius = const BorderRadius.all(Radius.circular(30)) , TextStyle ? style = const TextStyle(color: Colors.black, fontSize: 18) , Widget ? body , bool ? draggableBody = true })
const
Properties
body
→ Widget ?
A Widget that is placed in the sliding box and under the searching box.
final
borderRadius
→ BorderRadius ?
The corners of the search box are rounded by this.
final
color
→ Color ?
The color to fill the background of the SearchBox .
final
controller
→ TextEditingController
It can be used to control the state of search box text field.
gets a TextEditingController
final
draggableBody
→ bool ?
Allows toggling of draggability of the sliding box. if set this to false,
the sliding box cannot be dragged up or down when search box visible.
if set this to true, search box invisible when dragging.
final
hashCode
→ int
The hash code for this object.
no setter inherited
inputDecoration
→ InputDecoration ?
The decoration to show around the search box text field.
final
leading
→ Icon ?
A Icon Widget that is placed in left of the search box text field.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
style
→ TextStyle ?
The style to use for the text being edited.
final
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
flutter_sliding_box 1.1.5